import store from '@/store';
import router from '@/router';
import { paramsToQuery, getUrlSearchQuery } from "@/utils/";

export default {
  // 刷新当前tab页签 刷新参数无变化时使用
  refreshPage(obj) {
    const { path, query, matched } = router.currentRoute;
    if (obj === undefined) {
      matched.forEach((m) => {
        if (m.components && m.components.default && m.components.default.name) {
          if (!['Layout', 'ParentView'].includes(m.components.default.name)) {
            obj = { name: m.components.default.name, path: path, query: query };
          }
        }
      });
    }
    return store.dispatch('tagsView/delCachedView', obj).then(() => {
      const { path, query } = obj;
      router.replace({
        path: '/redirect' + path,
        query: query
      });
    });
  },
  // 关闭当前tab页签，打开新页签
  closeOpenPage(obj) {
    store.dispatch("tagsView/delView", router.currentRoute);
    if (obj !== undefined) {
      return router.push(obj);
    }
  },
  // 关闭当前tab页签并刷新 参数变动时用
  async refershCurrent(title, url, params) {
    // 删除当前页签
    await store.dispatch("tagsView/delView", router.currentRoute);
    const { tagRoutes, defaultRoutes } = this.createDifferentTabData(title, url, params);
    await store.dispatch('tagsView/addView', tagRoutes);
    router.push({
      ...defaultRoutes,
      path: `/redirect${defaultRoutes.fullPath}`,
    });
  },
  // 关闭指定tab页签
  closePage(obj) {
    if (obj === undefined) {
      return store.dispatch('tagsView/delView', router.currentRoute).then(({ visitedViews }) => {
        const latestView = visitedViews.slice(-1)[0];
        if (latestView) {
          return router.push(latestView.fullPath);
        }
        return router.push('/');
      });
    }
    return store.dispatch('tagsView/delView', obj);
  },
  // 关闭所有tab页签
  closeAllPage() {
    return store.dispatch('tagsView/delAllViews');
  },
  // 关闭左侧tab页签
  closeLeftPage(obj) {
    return store.dispatch('tagsView/delLeftTags', obj || router.currentRoute);
  },
  // 关闭右侧tab页签
  closeRightPage(obj) {
    return store.dispatch('tagsView/delRightTags', obj || router.currentRoute);
  },
  // 关闭其他tab页签
  closeOtherPage(obj) {
    return store.dispatch('tagsView/delOthersViews', obj || router.currentRoute);
  },
  // 添加tab页签
  async openPage(title, url, params = {}) {
    const { tagRoutes, defaultRoutes } = this.createDifferentTabData(title, url, params);
    await store.dispatch('tagsView/addView', tagRoutes);
    return router.push(defaultRoutes);
  },
  createDifferentTabData(title, url, params = {}) {
    const origin = location.origin;
    // 拼接完整路径
    const integrityUrl = `${origin}${url}`;
    const paramsResult = getUrlSearchQuery(integrityUrl);
    // 链接上带有参数 合并到query对象
    if (paramsResult && Object.keys(paramsResult).length) {
      params ? null : params = {};
      params = { ...JSON.parse(JSON.stringify(params)), ...paramsResult };
      url = url.slice(0, url.indexOf("?"));
    }
    const obj = { path: url, meta: { title }, fullPath: url, query: params, };
    const _obj = JSON.parse(JSON.stringify(obj));
    if (params && Object?.keys(params)?.length) {
      obj.fullPath = `${obj.path}${paramsToQuery(params) ? "?" + paramsToQuery(params) : ""}`;
      // 用于匹配 router跳转的fullPath 默认会 encodeURIComponent
      _obj.fullPath = `${_obj.path}${paramsToQuery(params, false) ? "?" + paramsToQuery(params, false) : ""}`;
    }
    return { tagRoutes: _obj, defaultRoutes: obj };
  },
  // 修改tab页签
  updatePage(obj) {
    return store.dispatch('tagsView/updateVisitedView', obj);
  }
};
